//
//  CustomerViewController.m
//  Salasee
//
//  Created by koda on 2014/01/24.
//
//

#import "SoundViewController.h"
#import "SoundManager.h"
#import "SoundDataSource.h"
#import "CommonPlaySound.h"
#import <AsReaderDockSDK/AsReaderDockSDK.h>

static NSString *kCellIdentifier = @"customerCell";

@interface SoundViewController ()
@property (nonatomic, strong) SoundManager *manager;
@property (nonatomic, strong) SoundDataSource *dataSource;
@property (nonatomic,strong) CommonPlaySound *common;

@end

@implementation SoundViewController

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil {
	self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
	if (self) {
		// Custom initialization
	}
	return self;
}

- (void)viewDidLoad {
	[super viewDidLoad];
	self.manager = [SoundManager sharedManager];
	[self setUpTableView];
	[self.tableView registerClass:[UITableViewCell class] forCellReuseIdentifier:kCellIdentifier];
	[self.tableView setDataSource:_dataSource];
	[self.tableView setDelegate:self];
	[self.tableView setSeparatorColor:[UIColor whiteColor]];
    self.navigationItem.title = @"App Sound Selection";
    self.common = [[CommonPlaySound alloc]init];
}

- (void)setUpTableView {
	self.dataSource = [[SoundDataSource alloc]initWithObserved:_manager
	                                                      keyPath:NSStringFromSelector(@selector(dataSource))
	                                               cellIdentifier:kCellIdentifier
	                                                    tableView:_tableView
	                                           configureCellBlock: ^(NSIndexPath *indexPath, UITableViewCell *cell) {
                                                   
                                                   //TODO: Cellの生成
                                                   NSUInteger offset = 0;
                                                   if (indexPath.section == 1) {
                                                       offset = [SoundManager sharedManager].originalSound.count;
                                                   }
                                                   NSString *filePath = [SoundManager sharedManager].dataSource[indexPath.row + offset];
                                                   NSArray *fileCopmponents = filePath.pathComponents;
                                                   NSString *fileName = fileCopmponents[fileCopmponents.count - 1];
                                                   NSString *dispName = nil;
                                                   
                                                 if (indexPath.section == 0) {
                                                       for (NSDictionary *dic in [SoundManager sharedManager].originalSound) {
                                                           for (NSString *key in dic.allKeys) {
                                                               if ([key isEqualToString:fileName]) {
                                                                   dispName = dic[key];
                                                               }
                                                           }
                                                       }
                                                   }
                                                  else {
                                                       if (!dispName) {
                                                           dispName = fileCopmponents[fileCopmponents.count - 1];
                                                       }
                                                   }
                                                     cell.textLabel.text = dispName;
                                                   NSUserDefaults *defauls = [NSUserDefaults standardUserDefaults];
                                                   NSString *savedPath = [defauls objectForKey:@"sound"];
                                                   
                                                   NSLog(@"filePath = %@",filePath);
                                                   NSLog(@"savedPath = %@",savedPath);
                                                   
                                                   if ([filePath isEqualToString:savedPath]) {
                                                       cell.accessoryType = UITableViewCellAccessoryCheckmark;
                                                   } else {
                                                       cell.accessoryType = UITableViewCellAccessoryNone;
                                                   }
                                               }];
   
}

- (void)didReceiveMemoryWarning {
	[super didReceiveMemoryWarning];
}

#pragma mark -- UITableview Delegate
- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    NSUInteger offset = 0;
    if (indexPath.section == 1) {
        offset = [SoundManager sharedManager].originalSound.count;
    }
    
    NSString *filePath = [SoundManager sharedManager].dataSource[indexPath.row + offset];
    NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
    [defaults setObject:filePath forKey:@"sound"];
    [defaults synchronize];
    for (int i = 0; i < [SoundManager sharedManager].countOfDataSource; i++) {
        [tableView cellForRowAtIndexPath:[NSIndexPath indexPathForRow:i inSection:0]].accessoryType = UITableViewCellAccessoryNone;
    }
    [tableView cellForRowAtIndexPath:indexPath].accessoryType = UITableViewCellAccessoryCheckmark;

    [[NSOperationQueue mainQueue] addOperationWithBlock:^{
        NSString * soundPath = [[NSUserDefaults standardUserDefaults] objectForKey:@"sound"];
        [self.common playSound:soundPath];
    }];
}
- (IBAction)onClickSendOff:(id)sender {
    UIAlertController *alert = [UIAlertController alertControllerWithTitle:@"Success" message:nil preferredStyle:UIAlertControllerStyleAlert];
    UIAlertAction* okAction = [UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction * action) {
        [[NSUserDefaults standardUserDefaults] setObject:@"" forKey:@"sound"];
        [[NSUserDefaults standardUserDefaults] synchronize];
        [self.tableView reloadData];
    }];
    [alert addAction:okAction];
    [self presentViewController:alert animated:YES completion:nil];
}

@end
